Behavior class

Constructors

Behavior({BehaviorType type = BehaviorType.speak, required Character character, String? dialog, Branch? branch, Position? position, StateEnum? state})

Properties

branch Branch?
getter/setter pair
character ↔ Character
getter/setter pair
dialog String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
position Position?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state StateEnum?
getter/setter pair
type BehaviorType
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited