Branch class

Constructors

Branch({required String id, required String description, required Scene? targetScene, Map<String, dynamic>? valueEffects})

Properties

description String
分支描述
final
hashCode int
The hash code for this object.
no setterinherited
id String
分支ID
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetScene Scene?
目标场景
final
valueEffects Map<String, dynamic>?
数值影响(待实现)
final

Methods

execute() → void
执行分支
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited