Scene class

Inheritance

Constructors

Scene({required String id, required String image, required List<Behavior> behaviors, String? next})

Properties

behaviors List<Behavior>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
finalinherited
image String
finalinherited
next String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

enter() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited